@@ -121,8 +121,8 @@ def main():
     show_default=True
     )
 @click.option('--no-lock', '-n', is_flag=True, default=False,
-    help='Do not apply a lock while executing the command (only applicable with plan)',
-    show_default=True
+    help='Do not apply a lock while executing the command (or set the TGWRAP_NO_LOCK environment variable, only applicable with plan)',
+    envvar='TGWRAP_NO_LOCK', show_default=True,
     )
 @click.option('--update', '-u', is_flag=True, default=False,
     help='Updates the source (and/or provider if applicable)',
@@ -180,8 +180,8 @@ def run(command, verbose, debug, dry_run, no_lock, update,
     show_default=True
     )
 @click.option('--no-lock', '-n', is_flag=True, default=False,
-    help='Do not apply a lock while executing the command (only applicable with plan)',
-    show_default=True
+    help='Do not apply a lock while executing the command (or set the TGWRAP_NO_LOCK environment variable, only applicable with plan)',
+    envvar='TGWRAP_NO_LOCK', show_default=True,
     )
 @click.option('--update', '-u', is_flag=True, default=False,
     help='Updates the source (and/or provider if applicable)',
@@ -263,8 +263,8 @@ def run_all(command, verbose, debug, dry_run, no_lock, update, exclude_external_
     help='Working directory, when omitted the current directory is used',
     )
 @click.option('--no-lock', '-n', is_flag=True, default=False,
-    help='Do not apply a lock while executing the command (only applicable with plan)',
-    show_default=True
+    help='Do not apply a lock while executing the command (or set the TGWRAP_NO_LOCK environment variable, only applicable with plan)',
+    envvar='TGWRAP_NO_LOCK', show_default=True,
     )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
@@ -346,8 +346,8 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir,
     ),
 )
 @click.option('--module', '-m', required=True,
-    help='Name of the lockiung module (or set LOCK_MODULE environment variable)',
-    envvar='LOCK_MODULE'
+    help='Name of the locking module (or set TGWRAP_LOCK_MODULE environment variable)',
+    envvar='TGWRAP_LOCK_MODULE'
     )
 @click.option('--auto-approve', '-a', is_flag=True, default=False,
     help='Do not ask for confirmation before applying planned changes (where applicable)',
@@ -386,8 +386,8 @@ def lock(module, auto_approve, verbose, dry_run, working_dir):
     ),
 )
 @click.option('--module', '-m', required=True,
-    help='Name of the lockiung module (or set LOCK_MODULE environment variable)',
-    envvar='LOCK_MODULE'
+    help='Name of the locking module (or set TGWRAP_LOCK_MODULE environment variable)',
+    envvar='TGWRAP_LOCK_MODULE'
     )
 @click.option('--auto-approve', '-a', is_flag=True, default=False,
     help='Do not ask for confirmation before applying planned changes (where applicable)',
